import unittest
import os
from reportlab.lib.pagesizes import A4
from reportlab.lib.units import inch
from pdf_creator import PDFCreator  # Certifique-se de que o nome do seu arquivo principal seja pdf_creator.py

class TestPDFCreator(unittest.TestCase):

    def setUp(self):
        # Cria um nome de arquivo temporário para o teste
        self.filename = "test_output.pdf"
        self.pdf = PDFCreator(self.filename)

    def test_add_title(self):
        # Testa se o título é adicionado corretamente
        self.pdf.add_title("Teste de Título")
        self.pdf.save()
        self.assertTrue(os.path.exists(self.filename))

    def test_add_paragraph(self):
        # Testa se o parágrafo é adicionado corretamente
        self.pdf.add_paragraph("Este é um parágrafo de exemplo. Você pode adicionar múltiplas linhas de texto.")
        self.pdf.save()
        self.assertTrue(os.path.exists(self.filename))

    def test_add_image(self):
        # Testa se a imagem é adicionada corretamente
        # Use uma imagem de exemplo que esteja no mesmo diretório ou forneça um caminho válido
        image_path = "example.jpg"  # Substitua pelo caminho da sua imagem
        if os.path.exists(image_path):
            self.pdf.add_image(image_path)
            self.pdf.save()
            self.assertTrue(os.path.exists(self.filename))

    def test_add_separator(self):
        # Testa se o separador é adicionado corretamente
        self.pdf.add_paragraph("Parágrafo com separador abaixo.").add_separator(thickness=2)
        self.pdf.save()
        self.assertTrue(os.path.exists(self.filename))

    def tearDown(self):
        # Remove o arquivo após o teste
        if os.path.exists(self.filename):
            os.remove(self.filename)

if __name__ == "__main__":
    unittest.main()



from reportlab.lib.pagesizes import A4
from reportlab.lib.units import inch, cm
from reportlab.pdfgen import canvas

class PDFCreator:
    def __init__(self, filename, width=A4[0], height=A4[1]):
        self.filename = filename
        self.canvas = canvas.Canvas(filename, pagesize=(width, height))
        self.width = width
        self.height = height
        self.cursor_y = height - inch  
        self.last_text_width = 0  

    def add_title(self, title, fontsize=24, x=None, y=None):
        x *= inch  
        y *= inch  
        self.canvas.setFont("Helvetica-Bold", fontsize)
        if y is not None:
            self.cursor_y = y
        if x is None:
            x = self.width / 2.0
        self.canvas.drawCentredString(x, self.cursor_y, title)
        self.cursor_y -= 1 * inch
        return self

    def add_paragraph(self, text, fontsize=12, spacing=0.5*inch, x=0, y=0):
        x *= inch  
        y *= inch  
        self.canvas.setFont("Helvetica", fontsize)
        if y is not None:
            self.cursor_y = y
        if x is None:
            x = inch
        text_object = self.canvas.beginText(x, self.cursor_y)
        text_object.setTextOrigin(x, self.cursor_y)
        text_object.textLines(text)
        self.canvas.drawText(text_object)
        self.cursor_y -= spacing 
        self.last_text_width = self.canvas.stringWidth(text, "Helvetica", fontsize)
        return self

    def add_image(self, image_path, x=inch, y=None, width=2*inch, height=2*inch):
        x *= inch  
        y *= inch  
        if y is None:
            y = self.cursor_y - height - inch
        self.canvas.drawImage(image_path, x, y, width, height)
        self.cursor_y = y
        return self

    def add_separator(self, thickness=1, start_x=inch, y_position=None, width=None):
        if y_position is None:
            y_position = self.cursor_y - 0.3 * inch
        if width is None:
            width = self.width - 2 * inch

        self.canvas.setLineWidth(thickness)
        self.canvas.line(start_x, y_position, start_x + width, y_position)
        self.cursor_y = y_position - 0.3 * inch  
        return self
    def add_vertical_line(self, start_y, end_y, x, thickness=1):
        x *= inch  
        start_y *= inch  
        end_y *= inch  
        
        self.canvas.setLineWidth(thickness)
        self.canvas.line(x, start_y, x, end_y)
        return self
    
    def add_square(self, width, height, x=inch, y=None):
        x *= inch 
        y *= inch  
        width=width*inch
        height=height*inch
        if y is None:
            y = self.cursor_y - height
        self.canvas.rect(x, y, width, height)
        self.cursor_y = y - 0.3 * inch  
        return self
    
    def add_multiples_squares(self, squares, width=None, height=None, x=inch, y=inch):
        x *= inch 
        y *= inch  
        
        if width is None:
            width = 1 * inch 
        if height is None:
            height = 1 * inch  
        
        for sq_x, sq_y, sq_width, sq_height in squares:
            self.canvas.rect(x + sq_x * inch, y - sq_y * inch, sq_width * inch, sq_height * inch)
            self.cursor_y -= sq_height * inch + 0.1 * inch  
        return self
    def save(self):
        self.canvas.save()
        return self


from setuptools import setup, find_packages

from pathlib import Path
this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()
setup(
    name='pdf-Creator-mr',
    version='0.0.4',
    packages=find_packages(),
    install_requires=[
        'reportlab',
    ],
    description='A simple library for creating PDFs in Python. USE: Django,tkinter....',
    long_description=long_description,
    long_description_content_type='text/markdown',
    author='Mateus Reis',
    author_email='mateussgp12@gmail.com',
    url='https://github.com/mateusdosreisf/pdf_generator',
)
